@@ -38,6 +38,7 @@ typedef struct  {
     BOOL mActive;
 
     BOOL mVD;                   // 仮想ディレクトリ開始
+    BOOL mVD2;                  // ls -al出力の仮想ディレクトリ開始
 
     vector_obj* mHistory;
     int mHistoryCursor;
@@ -96,7 +97,13 @@ void filer_vd_start(int dir);
 void filer_vd_add(int dir, char* fname);
 void filer_vd_end(int dir);
 
-BOOL filer_add_keycommand(int meta, int key, char* ftype, char* command, char* fname);
+void filer_vd2_start(int dir);
+void filer_vd2_end(int dir);
+void filer_vd2_add(int dir, char* fname, char* linkto, struct stat64 stat_, struct stat64 lstat_, char* user, char* group);
+
+BOOL filer_add_keycommand(char* mode, int meta, int key, char* ftype, char* command, char* fname);
+BOOL filer_add_keycommand2(char* mode, int meta, int key, char* ftype, sBlock* block, char* fname);
+BOOL filer_change_mode(char* mode);
 
 int adir();
 int sdir();
