@@ -355,7 +355,7 @@ static void usage()
 static void version()
 {
     printf("mfiler3 version %s with shell scripting system saphire version %s.", getenv("VERSION"), getenv("SAPHIRE_VERSION"));
-    puts("This program is a traditional Japanese style 2pain file manager with a embedded shell scripting system \"saphire\". mfiler3 is developped by Daisuke Minato.");
+    puts("This program is a 2pain file manager with a embedded shell scripting system \"saphire\". mfiler3 is developped by ab25cq.");
     puts("compiled with");
 
 #if defined(HAVE_MIGEMO_H)
@@ -750,7 +750,7 @@ int main(int argc, char* argv[])
 #endif
 
     /// ファイラでもスクリプトでも共通の環境変数を初期化 ///
-    setenv("VERSION", "4.4.7", 1);
+    setenv("VERSION", "4.4.8", 1);
 
     /// mfiler3のホームディレクトリを保存しておく ///
     char* home = getenv("HOME");
