@@ -24,8 +24,14 @@ static sMenuItem* sMenuItem_new(char* name, int key, char* cmd) {
 
 static void sMenuItem_delete(sMenuItem* self)
 {
+    FREE(self->mName);
+    FREE(self->mCmd);
+
+    FREE(self);
 }
 
+void sMenu_delete(sMenu* self);
+
 sMenu* sMenu_new(char* title)
 {
     sMenu* self = MALLOC(sizeof(sMenu));
@@ -36,6 +42,9 @@ sMenu* sMenu_new(char* title)
 
     self->mMenuItems = VECTOR_NEW(5);
 
+    sMenu* menu = hash_item(gMenu, title);
+    if(menu) sMenu_delete(menu);
+
     hash_put(gMenu, title, self);
 
     return self;
@@ -43,6 +52,13 @@ sMenu* sMenu_new(char* title)
 
 void sMenu_delete(sMenu* self)
 {
+    int i;
+    for(i=0; i<vector_size(self->mMenuItems); i++) {
+        sMenuItem_delete(vector_item(self->mMenuItems, i));
+    }
+    vector_delete(self->mMenuItems);
+
+    FREE(self);
 }
 
 sMenu* gActiveMenu = NULL;
@@ -58,6 +74,12 @@ void menu_init()
 
 void menu_final()
 {
+    hash_it* it = hash_loop_begin(gMenu);
+    while(it) {
+        sMenu_delete(hash_loop_item(it));
+        it = hash_loop_next(it);
+    }
+    hash_delete(gMenu);
 }
 
 ///////////////////////////////////////////////////
@@ -115,12 +137,14 @@ void menu_input(sMenu* self, int meta, int key)
         view(TRUE);
         mrefresh();
         
-        sRFd* pipein = sRFd_new(STDIN_FILENO);
-        sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+        sRFd* pipein = RFD_NEW(STDIN_FILENO);
+        sWFd* pipeout = WFD_NEW(STDOUT_FILENO);
         saphire_init_stack_frame();
         int rcode = saphire_shell(item->mCmd, NULL, pipeout, pipein, STDERR_FILENO);
         saphire_sweep();
         sWFd_flash(pipeout);
+        sWFd_delete(pipeout);
+        sRFd_delete(pipein);
 
         mclear();
     }
@@ -139,12 +163,14 @@ void menu_input(sMenu* self, int meta, int key)
                 view(TRUE);
                 mrefresh();
                 
-                sRFd* pipein = sRFd_new(STDIN_FILENO);
-                sWFd* pipeout = sWFd_new(STDOUT_FILENO);
+                sRFd* pipein = RFD_NEW(STDIN_FILENO);
+                sWFd* pipeout = WFD_NEW(STDOUT_FILENO);
                 saphire_init_stack_frame();
                 int rcode = saphire_shell(item->mCmd, NULL, pipeout, pipein, STDERR_FILENO);
                 saphire_sweep();
                 sWFd_flash(pipeout);
+                sWFd_delete(pipeout);
+                sRFd_delete(pipein);
             }
         }
         
